# CSV_TO_DB_CONVERTER
It takes a CSV file as input and converts 
and save the data into a default set DB (fileupload).
The table name will consist of the name of the file user is uploading.
After a successful upload user can perform CRUD operations on the file data using a localhost server.

## Installation
pip install csvtodb-converter-saatwikmehta


## License 
© 2022 Saatwik Mehta

This repository is licensed under the MIT license. See LICENSE for details.


